@@ -3,9 +3,7 @@ kcv.nn <-
            linout = FALSE, censored = FALSE, skip = FALSE, rang = 0.5, 
            parallel = FALSE) 
 {
-    if (!is.factor(y)) {
-      y <- factor(y)
-    }
+    if (!is.factor(y)) {y <- factor(y)}
     if (length(unique(y)) == 1L) {
       stop("Input 'y' must contain some variation (i.e., cannot contain \n
            only a single type of label).")
@@ -19,9 +17,7 @@ kcv.nn <-
       if (length(unique(nfolds)) != 1L) {
         stop("Input 'nfolds' must contain only a single value.")
       }
-      if ((nfolds %% 1) != 0) {
-        stop("Input 'nfolds' must be an integer.")
-      }
+      if ((nfolds %% 1) != 0) {stop("Input 'nfolds' must be an integer.")}
       if ((nfolds < 2) | (nfolds > length(y))) {
         stop("Input 'nfolds' must be an integer between 2 and the \n
              number of observations, inclusive. Alternatively, the \n
@@ -45,9 +41,7 @@ kcv.nn <-
       stop("Input 'foldid' must contain the number of unique values equal to \n
            input 'nfolds'.")
     }
-    if (is.null(weights)) {
-      weights <- as.numeric((table(y)[y] / length(y)))
-    }
+    if (is.null(weights)) {weights <- as.numeric((table(y)[y] / length(y)))}
     x <- as.matrix(x)
     weights <- as.matrix(weights)                                               
     grid.row <- nrow(nn.grid)
@@ -64,17 +58,12 @@ kcv.nn <-
                         con.ytrain <- model.matrix(~y.train - 1, data.ytrain)
                         stortune <- matrix(rep(0, grid.row), ncol = 1)
                         for (yy in 1:grid.row) {
-                           nn.fit <- nnet(x = x.train, 
-                                          y = con.ytrain, 
-                                          trace = FALSE, 
-                                          size = nn.grid[yy, 1], 
+                           nn.fit <- nnet(x = x.train, y = con.ytrain, 
+                                          trace = FALSE, size = nn.grid[yy, 1], 
                                           decay = nn.grid[yy, 2], 
-                                          linout = linout, 
-                                          weights = trweights,
-                                          censored = censored, 
-                                          skip = skip, 
-                                          rang = rang, 
-                                          MaxNWts = 10000)
+                                          linout = linout, weights = trweights,
+                                          censored = censored, skip = skip, 
+                                          rang = rang, MaxNWts = 10000)
                            nn.pred <- predict(nn.fit, newdata = x.test, 
                                               type = 'raw')
                            y.pred <- as.numeric((apply(nn.pred, 1, 
